------------------------------------------------------------------------------
-- MakeMeGetMyMain - Alarms you when something happens to your character
------------------------------------------------------------------------------
-- Trigger_Say.lua - Triggered if someone says something special
--
-- Author: Expelliarm5s / October 2020 / All Rights Reserved
--
-- Version 1.1.6
------------------------------------------------------------------------------
-- luacheck: ignore 212 globals DLAPI

local addonName, addon = ...
local modle = addon:NewModule("Say", "AceEvent-3.0", "AceConsole-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale(addonName)
-- local private = {}
------------------------------------------------------------------------------

function modle:ModuleName()
	return modle.moduleName
end

function modle:ModuleIcon()
	return "INTERFACE\\ICONS\\Ability_Suffocate"
end

function modle:TriggerName()
	return L["Character says a word!"]
end

function modle:TriggerDesc()
	return L["Alarm fires when someone says a word."]
end

function modle:Login()
	modle:RegisterEvent("CHAT_MSG_SAY")
end

function modle:GetOptions()
	local options = {
		type = "input",
		name = L["List of Words:"],
		desc = L["Words to trigger an alarm when someone says the word, e.g. \"Multiboxer, Howdy\" or \"*\" for any word."],
		width = "full",
		get = function(info)
			return addon.db.global.SayWordList
		end,
		set = function(info, value)
			if value then
				addon.db.global.SayWordList = value
			end
		end,
	}
	return options
end

function modle:CHAT_MSG_SAY(event, arg1, arg2)
	addon:DebugPrintf(modle.moduleName .. "~  %s: '%s' from %s", tostring(event), tostring(arg1), tostring(arg2))
	if addon.isEnabled and addon.db.global[modle.moduleName] then
		local wordList = addon.db.global.SayWordList .. ","
		local found = false
		wordList:gsub("([a-z0-9A-Z*]+),",
			function(j)
				j = gsub(j, "^ ", "")
				j = gsub(j, " $", "")
				if j == "*" then
					found = true
				else
					-- addon:DebugPrintf(modle.moduleName .. "~j = %s", tostring(j))
					if arg1 and type(arg1) == "string" then
						for w in arg1:gmatch("([a-z0-9A-Z]+)") do
							if w and strlower(w) == strlower(j) then
								addon:DebugPrintf(modle.moduleName .. "~  found %s in word list", tostring(j))
								found = true
							end
						end
					end
				end
			end)
		if found then
			addon:DebugPrintf(modle.moduleName .. "~  -> GUI:Fire(%s)", modle.moduleName)
			addon:Printf(format(L["Module %s: %s (from %s)"], modle.moduleName, modle:TriggerName(), tostring(arg2)))
			if addon.GUI.Fire then
				addon.GUI:Fire(modle.moduleName)
			end
			return
		end
	end
end

-- EOF